<?php

/**
 * @file
 * Contains \Drupal\body_inject\ProfileListBuilder.
 */

namespace Drupal\body_inject;

use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Url;
use Drupal\block_content\Entity\BlockContent;

/**
 * Defines a class to build a listing of profile entities.
 *
 * @see \Drupal\body_inject\Entity\Profile
 */
class ProfileListBuilder extends ConfigEntityListBuilder {

  /**
   * {@inheritdoc}
   */
  public function buildHeader() {
      $header['title'] = t('Profile');
      $header['description'] = [
          'data' => t('Description'),
          'class' => [RESPONSIVE_PRIORITY_MEDIUM],
      ];
      $header['node_type'] = [
        'data' => t('Node Type'),
        'class' => [RESPONSIVE_PRIORITY_MEDIUM],
      ];
    $header['block_reference'] = [
      'data' => t('Block'),
      'class' => [RESPONSIVE_PRIORITY_MEDIUM],
    ];

    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {
    /** @var \Drupal\body_inject\ProfileInterface $body_injectProfile */
    $body_injectProfile = $entity;
    $row['label'] = $body_injectProfile->label();
    $row['description']['data'] = ['#markup' => $body_injectProfile->getDescription()];
    $row['node_type']['data'] = ['#markup' => $body_injectProfile->getNodeType()];

    //get label. add this to the Profile Class?
    $block = BlockContent::load($body_injectProfile->getBlock());
    if($block == null) {
      $block_label = 'invaild block/deleted block';
    } else {
      $block_label = $block->label();
    }
    $row['block_reference']['data'] = ['#markup' => $block_label];

    return $row + parent::buildRow($entity);
  }

  /**
   * {@inheritdoc}
   */
  public function getDefaultOperations(EntityInterface $entity) {
    $operations = parent::getDefaultOperations($entity);

    if (isset($operations['edit'])) {
      $operations['edit']['title'] = t('Edit profile');
    }


    return $operations;
  }

}
